===============
Venus Dashboard
===============

.. image:: https://governance.openstack.org/tc/badges/venus-dashboard.svg
    :target: https://governance.openstack.org/tc/reference/tags/index.html

.. Change things from this point on

Venus Dashboard provides a dashboard for OpenStack Log Management Service (venus).

About Venus
-----------

In light of the problems and needs of retrieval, storage and analysis etc.
of logs on the OpenStack platform, we developed the OpenStack log management
module Venus.

This project can provide a one-stop solution to log collection,
cleaning, indexing, analysis, alarm, visualization, report generation and
other needs, which involves helping operator or maintainer to quickly solve
retrieve problems, grasp the operational health of the platform, and improve
the level of platform management.

Additionally, this project plans to use machine learning algorithms to
quickly locate IT failures and root causes, and improve operation and
maintenance efficiency.
